mysql.constants.field_flags

Package mysql :: Package constants :: Module field_flags |
[hide private]
[frames] | no frames]

# Module field_flags

Flags used in the `flags` attribute of the mysql.result.Field object.

Note that the flags attribute in the Field object may contain internally used flags that are not documented here.

Variables | [hide private]
`` | AUTO_INCREMENT = `512` Field has the AUTO_INCREMENT attribute.
`` | BINARY = `128` Field has the BINARY attribute.
`` | KNOWN_FLAGS = `751` Bitwise OR of all documented flags.
`` | MULTIPLE_KEY = `8` Field is part of a non-unique key.
`` | NOT_NULL = `1` Field can't be NULL.
`` | PRI_KEY = `2` Field is part of a primary key.
`` | UNIQUE_KEY = `4` Field is part of a unique key.
`` | UNSIGNED = `32` Field has the UNSIGNED attribute.
`` | ZEROFILL = `64` Field has the ZEROFILL attribute.
`` | __version__ = `'$Revision: 1.3 $'`

Variables Details | [hide private]

    ### AUTO_INCREMENT Field has the AUTO_INCREMENT attribute. Value:
        512

    ### BINARY Field has the BINARY attribute. Value:
        128

    ### KNOWN_FLAGS Bitwise OR of all documented flags. Value:
        751

    ### MULTIPLE_KEY Field is part of a non-unique key. Value:
        8

    ### NOT_NULL Field can't be NULL. Value:
        1

    ### PRI_KEY Field is part of a primary key. Value:
        2

    ### UNIQUE_KEY Field is part of a unique key. Value:
        4

    ### UNSIGNED Field has the UNSIGNED attribute. Value:
        32

    ### ZEROFILL Field has the ZEROFILL attribute. Value:
        64

    ### __version__ Value:
        '$Revision: 1.3 $'